import {
  select,
  json,
  tsv,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event
} from 'd3';
import { feature } from 'topojson';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

let selectedCountry =  null;

const onClick = id => {
  selectedCountry = id;
  render(selectedCountry);
}

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

const promise = {
  Promise.all([
  tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1.1.4/world/50m.json')
  ]).then(([tsvData, topoJSONdata]) => {
  
    const countryName = tsvData.reduce((accumulator, d) => {
      accumulator[d.iso_n3] = d.name;
      return accumulator;
    }, {});
  })
  const countries = feature(topoJSONdata, topoJSONdata.objects.countries);
  return countries;
}

const countries = promise();


const render = selectedCountry => (
g.selectAll('path').data(countries.features)
  .enter().append('path')
    .attr('class', 'country')
    .attr('d', pathGenerator)
  .merge('path')
    .attr('fill', d=>
      d.countryName[d.id] === selectedCountry
        ? 'red'
        : 'none')
    .on('click', d => {
      onClick(countryName[d.id]);
      console.log("hello");
    })   

  .append('title')
    .text(d => countryName[d.id]);
)

render(selectedCountry);
 